package net.wanji.web.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import net.wanji.feign.pojo.result.JsonViewObject;
import net.wanji.feign.pojo.vo.*;
import net.wanji.feign.service.UtcFeignClients;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Objects;

/**
 * @author duanruiming
 * @date 2023/01/04 16:10
 */
@Api(value = "SignalServiceController", description = "信号控制")
@RequestMapping("/controlCommand")
@RestController
@SuppressWarnings("all")
public class SignalCommandController {

    @Autowired
    private UtcFeignClients utcFeignClients;

    @ApiOperation(value = "信号机方案下发-基础方案下发", notes = "信号机方案下发-基础方案下发")
    @PostMapping("/schemeSend")
    public JsonViewObject schemeSend(@RequestBody @Validated SchemeSendVO schemeSendVO) {
        JsonViewObject jsonViewObject = utcFeignClients.schemeSend(schemeSendVO);
        if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
            return jsonViewObject.fail("信号机方案下发-基础方案下发UTC服务调用异常");
        }
        return jsonViewObject.success();
    }

    @ApiOperation(value = "计划下发-计划信息、时段信息", notes = "计划下发-计划信息、时段信息")
    @PostMapping("/planSend")
    public JsonViewObject planSend(@RequestBody @Validated PlanSendVO planSendVO) throws Exception {
        JsonViewObject jsonViewObject = utcFeignClients.planSend(planSendVO);
        if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
            return jsonViewObject.fail("计划下发-计划信息、时段信息UTC服务调用异常");
        }
        return jsonViewObject;
    }

    @ApiOperation(value = "时间表下发-时间表信息", notes = "时间表下发-时间表信息")
    @PostMapping("/scheduleSend")
    public JsonViewObject scheduleSend(@RequestBody @Validated ScheduleSendVO scheduleSendVO) throws Exception {
        JsonViewObject jsonViewObject = utcFeignClients.scheduleSend(scheduleSendVO);
        if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
            return jsonViewObject.fail("时间表下发-时间表信息UTC服务调用异常");
        }
        return jsonViewObject;
    }

    @ApiOperation(value = "相位配时下发-（下发相位参数）", notes = "相位配时下发-（下发相位参数）")
    @PostMapping("/phaseTimingSend")
    public JsonViewObject phaseTimingSend(@RequestBody @Validated PhaseTimingSendVO phaseTimingSendVO) throws Exception {
        JsonViewObject jsonViewObject = utcFeignClients.phaseTimingSend(phaseTimingSendVO);
        if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
            return jsonViewObject.fail("相位配时下发-（下发相位参数）UTC服务调用异常");
        }
        return jsonViewObject;
    }

    @ApiOperation(value = "灯态控制-路口全红/黄闪/关灯控制/恢复", notes = "灯态控制-路口全红/黄闪/关灯控制/恢复")
    @PostMapping("/lampStateControl")
    public JsonViewObject allRedControl(@RequestBody @Validated ControlCommandVO commandVO) throws Exception {
        Integer controlType = commandVO.getControlType();
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        if (1 == controlType) {
            jsonViewObject = utcFeignClients.allRedControl(commandVO);
        }
        if (2 == controlType) {
            jsonViewObject = utcFeignClients.yellowLightControl(commandVO);
        }
        if (3 == controlType) {
            jsonViewObject = utcFeignClients.closeLightControl(commandVO);
        }
        if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
            return jsonViewObject.fail("灯态控制UTC服务调用异常");
        }
        return jsonViewObject;
    }


    @ApiOperation(value = "步进控制-步进控制/恢复", notes = "步进控制-步进控制/恢复")
    @PostMapping("/stepControl")
    public JsonViewObject stepControl(@RequestBody @Validated StepControlVO stepControlVO) throws Exception {
        JsonViewObject jsonViewObject = utcFeignClients.stepControl(stepControlVO.getCode(), stepControlVO.getCommand(), stepControlVO.getStepNum());
        if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
            return jsonViewObject.fail("步进控制-步进控制/恢复UTC服务调用异常");
        }
        return jsonViewObject;
    }

    @ApiOperation(value = "恢复时间表-恢复路口时间表执行", notes = "恢复时间表-恢复路口时间表执行")
    @PostMapping("/recoverSchedule")
    public JsonViewObject recoverSchedule(@RequestParam String code) throws Exception {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        jsonViewObject = utcFeignClients.recoverSchedule(code);
        if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
            return jsonViewObject.fail("恢复时间表-恢复路口时间表执行UTC服务调用异常");
        }
        return jsonViewObject;
    }

    @ApiOperation(value = "锁定控制-相位锁定/解锁", notes = "锁定控制-相位锁定/解锁")
    @PostMapping(value = "/lockControl")
    public JsonViewObject lockControl(@RequestBody @Validated ControlCommandVO commandVO) throws Exception {
        JsonViewObject jsonViewObject = utcFeignClients.lockControl(commandVO);
        if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
            return jsonViewObject.fail("锁定控制-相位锁定/解锁UTC服务调用异常");
        }
        return jsonViewObject;
    }

    @ApiOperation(value = "相位差下发", notes = "相位差下发")
    @PostMapping("/phaseDiffSend")
    public JsonViewObject phaseDiffSend(HttpServletRequest httpServletRequest) {
        JsonViewObject jsonViewObject = utcFeignClients.phaseDiffSend();
        if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
            return jsonViewObject.fail("相位差下发UTC服务调用异常");
        }
        return jsonViewObject;
    }

}
