package net.wanji.web.service.scheme.impl;

import net.wanji.web.common.exception.WeekException;
import net.wanji.web.dto.RunningPlanDTO;
import net.wanji.web.mapper.scheme.CrossPlanMapper;
import net.wanji.web.mapper.scheme.CrossSchemeMapper;
import net.wanji.web.mapper.scheme.CrossSectionMapper;
import net.wanji.web.po.scheme.CrossPlanPO;
import net.wanji.web.po.scheme.CrossSchemePO;
import net.wanji.web.po.scheme.CrossSectionPO;
import net.wanji.web.service.scheme.RunningPlanService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

/**
 * @author Kent HAN
 * @date 2023/1/28 16:41
 */
@Service
public class RunningPlanServiceImpl implements RunningPlanService {
    private final CrossPlanMapper crossPlanMapper;
    private final CrossSchemeMapper crossSchemeMapper;
    private final CrossSectionMapper crossSectionMapper;

    public RunningPlanServiceImpl(CrossPlanMapper crossPlanMapper, CrossSchemeMapper crossSchemeMapper, CrossSectionMapper crossSectionMapper) {
        this.crossPlanMapper = crossPlanMapper;
        this.crossSchemeMapper = crossSchemeMapper;
        this.crossSectionMapper = crossSectionMapper;
    }

    @Override
    @Transactional
    public void saveRunningPlan(RunningPlanDTO runningPlanDTO) {
        String crossId = runningPlanDTO.getCrossId();
        // 验证特殊日期
        List<RunningPlanDTO.SchedulesPlanListElement> schedulesPlanList = runningPlanDTO.getSchedulesPlanList();
        for (RunningPlanDTO.SchedulesPlanListElement schedulesPlan : schedulesPlanList) {
            List<Integer> week = schedulesPlan.getWeek();
            Date specialDate = schedulesPlan.getSpecialDate();
            if (week != null && week.size() > 0 && specialDate != null) {
                throw new WeekException("不能同时有星期选择和日期选择");
            }
        }
        // 清空之前计划
        crossPlanMapper.deleteByCrossId(crossId);
        crossSectionMapper.deleteByCrossId(crossId);
        // 保存计划数据
        List<RunningPlanDTO.DailyPlanListElement> dailyPlanList = runningPlanDTO.getDailyPlanList();
        for (RunningPlanDTO.DailyPlanListElement dailyPlan : dailyPlanList) {
            // 更新计划表获取计划ID
            CrossPlanPO crossPlanPO = new CrossPlanPO();
            crossPlanPO.setPlanNo(dailyPlan.getPlanNo());
            crossPlanPO.setName(dailyPlan.getName());
            crossPlanPO.setCrossId(crossId);
            crossPlanMapper.insertOne(crossPlanPO);
            Integer crossPlanId = crossPlanPO.getId();
            // 根据路口ID和方案名获取方案ID
            String schemeName = dailyPlan.getSchemeName();
            CrossSchemePO crossSchemePO = crossSchemeMapper.selectByCrossIdAndSchemeName(crossId, schemeName);
            Integer schemeId = crossSchemePO.getId();
            // 更新时段表
            CrossSectionPO crossSectionPO = new CrossSectionPO();
            String startTime = dailyPlan.getStartTime();
            String endTime = dailyPlan.getEndTime();
            String s = startTime + endTime;
            String sectionNo = s.replaceAll(":", "");
            crossSectionPO.setSectionNo(sectionNo);
            crossSectionPO.setStartTime(startTime);
            crossSectionPO.setEndTime(endTime);
            crossSectionPO.setCrossId(crossId);
            crossSectionPO.setPlanId(crossPlanId);
            crossSectionPO.setControlMode(1); // todo 暂时只有定周期
            crossSectionPO.setSchemeId(schemeId);
            crossSectionMapper.insertOne(crossSectionPO);
        }

        // 保存调度数据
        // 更新调度表获取调度ID
        // 根据路口ID和计划名获取计划ID
        // 更新调度计划关系表
    }
}
