package net.wanji.web.task;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import lombok.extern.slf4j.Slf4j;
import net.wanji.feign.pojo.result.JsonViewObject;
import net.wanji.feign.service.UtcFeignClients;
import net.wanji.web.entity.TDeviceStatusInfo;
import net.wanji.web.mapper.TDeviceStatusMapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * @author duanruiming
 * @date 2023/01/03 10:43
 */
@Component
@Slf4j
public class SignalStatusTask {

    @Autowired
    private UtcFeignClients utcFeignClients;

    @Autowired
    private TDeviceStatusMapper tDeviceStatusMapper;

    @Scheduled(fixedRate = 1 * 60 * 1000)
    public void syncSignalStatus() {
        try {
            JsonViewObject jsonViewObject = utcFeignClients.runningStatusAlarm();
            if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
                log.error("定时任务同步信号机设备状态utcService调用异常");
                return;
            }
            List<Map<String, Object>> content = (List<Map<String, Object>>) jsonViewObject.getContent();
            content.forEach(map -> {
                Map<String, Object> result = map;
                String signalId = (String) result.get("signalId");
                Integer currentSignalStatus = result.get("status") == null ? 0 : (Integer) result.get("status");
                Integer currentFaultType = result.get("faultType") == null ? 0 : (Integer) result.get("faultType");

                // 当前服务数据库状态
                LambdaQueryWrapper<TDeviceStatusInfo> lambdaQueryWrapper = new LambdaQueryWrapper<>();
                if (StringUtils.isNotEmpty(signalId)) {
                    lambdaQueryWrapper.eq(TDeviceStatusInfo::getCode, signalId);
                    TDeviceStatusInfo tDeviceStatusInfo = tDeviceStatusMapper.selectOne(lambdaQueryWrapper);
                    if (isExucuteUpdate(currentSignalStatus, currentFaultType, tDeviceStatusInfo)) {
                        tDeviceStatusInfo.setStatus(currentSignalStatus);
                        tDeviceStatusInfo.setFaultType(currentFaultType);
                        tDeviceStatusMapper.updateById(tDeviceStatusInfo);
                    }
                }
            });
        } catch (Exception e) {
            log.error("定时任务同步信号机设备状态远程utcService调用异常", e);
        }
    }

    private static boolean isExucuteUpdate(Integer currentSignalStatus, Integer currentFaultType, TDeviceStatusInfo tDeviceStatusInfo) {
        return Objects.nonNull(tDeviceStatusInfo) && (currentSignalStatus != tDeviceStatusInfo.getStatus() || currentFaultType != tDeviceStatusInfo.getFaultType());
    }
}
